@@ -1,3 +1,4 @@
+#!/usr/bin/python
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 from __future__ import print_function
@@ -26,7 +27,7 @@ import json
 import warnings
 
 from six import string_types
-from six.moves import html_parser
+from six.moves.html_parser import HTMLParser
 from six import print_ as print
 
 from requests_oauthlib import OAuth1
@@ -53,9 +54,11 @@ if 'pydevd' not in sys.modules:
     except NotImplementedError:
         pass
 
-encoding = sys.getdefaultencoding()
-if encoding != 'UTF8':
-    warnings.warn("Python default encoding is '%s' instead of 'UTF8' which means that there is a big change of having problems. Possible workaround http://stackoverflow.com/a/17628350/99834" % encoding)
+warnings.simplefilter('default')
+
+#encoding = sys.getdefaultencoding()
+# if encoding != 'UTF8':
+#    warnings.warn("Python default encoding is '%s' instead of 'UTF8' which means that there is a big change of having problems. Possible workaround http://stackoverflow.com/a/17628350/99834" % encoding)
 
 
 def translate_resource_args(func):
@@ -153,6 +156,11 @@ class JIRA(object):
         """
         if options is None:
             options = {}
+            if server and hasattr(server, 'keys'):
+                warnings.warn("Old API usage, use JIRA(url) or JIRA(options={'server': url}, when using dictionary always use named parameters.", DeprecationWarning)
+                options = server
+                server = None
+
         if server:
             options['server'] = server
         if async:
@@ -186,11 +194,6 @@ class JIRA(object):
         # We need version in order to know what API calls are available or not
         self._version = tuple(self.server_info()['versionNumbers'])
 
-    def __del__(self):
-        # that is performing the logout by killing the session
-        self.async_do()
-        self.kill_session()
-
 # Information about this client
 
     def client_info(self):
@@ -536,7 +539,7 @@ class JIRA(object):
         :param fields: comma-separated string of issue fields to include in the results
         :param expand: extra information to fetch inside each resource
         """
-        issue = Issue(self._options, self._session, self)
+        issue = Issue(self._options, self._session)
 
         params = {}
         if fields is not None:
@@ -616,7 +619,7 @@ class JIRA(object):
     @translate_resource_args
     def assign_issue(self, issue, assignee):
         """
-        Assign an issue to a user. None will set it to unassigned. -1 will set it to Automatic.
+        Assign an issue to a user.
 
         :param issue: the issue to assign
         :param assignee: the user to assign the issue to
@@ -873,8 +876,7 @@ class JIRA(object):
         """
         url = self._get_url('issue/' + str(issue) + '/watchers')
         params = {'username': watcher}
-        result = self._session.delete(url, params=params)
-        return result
+        self._session.delete(url, params=params)
 
     @translate_resource_args
     def worklogs(self, issue):
@@ -899,7 +901,7 @@ class JIRA(object):
 
     @translate_resource_args
     def add_worklog(self, issue, timeSpent=None, adjustEstimate=None,
-                    newEstimate=None, reduceBy=None, comment=None, started=None, user=None):
+                    newEstimate=None, reduceBy=None, comment=None):
         """
         Add a new worklog entry on an issue and return a Resource for it.
 
@@ -909,7 +911,6 @@ class JIRA(object):
         time estimate of the issue. The value can either be ``new``, ``leave``, ``manual`` or ``auto`` (default).
         :param newEstimate: the new value for the remaining estimate field. e.g. "2d"
         :param reduceBy: the amount to reduce the remaining estimate by e.g. "2d"
-        :param started: Moment when the work is logged, if not specified will default to now
         :param comment: optional worklog comment
         """
         params = {}
@@ -925,21 +926,7 @@ class JIRA(object):
             data['timeSpent'] = timeSpent
         if comment is not None:
             data['comment'] = comment
-        elif user:
-            # we log user inside comment as it doesn't always work
-            data['comment'] = user
 
-        if started is not None:
-            # based on REST Browser it needs: "2014-06-03T08:21:01.273+0000"
-            data['started'] = started.strftime("%Y-%m-%dT%H:%M:%S.000%z")
-        if user is not None:
-            data['author'] = { "name": user,
-                               'self': self.JIRA_BASE_URL + '/rest/api/2/user?username=' + user,
-                               'displayName': user,
-                               'active': False
-                               }
-            data['updateAuthor'] = data['author']
-        # TODO: report bug to Atlassian: author and updateAuthor parameters are ignored.
         url = self._get_url('issue/{}/worklog'.format(issue))
         r = self._session.post(url, params=params, headers={'content-type': 'application/json'}, data=json.dumps(data))
         raise_on_error(r)
@@ -1735,7 +1722,7 @@ class JIRA(object):
             try:
                 return mimetypes.guess_type("f." + imghdr.what(0, buff))[0]
             except (IOError, TypeError):
-                logging.warning("Couldn't detect content type of avatar image"
+                print("WARNING: Couldn't detect content type of avatar image"
                       ". Specify the 'contentType' parameter explicitly.")
                 return None
 
@@ -1759,8 +1746,7 @@ class JIRA(object):
             'id': '',
             'Preview': 'Preview',
         }
-
-        r = self._session.post(url, headers=self._options['headers'], data=payload)
+        r = self._session.post(url, headers={'X-Atlassian-Token': 'nocheck', 'Cache-Control': 'no-cache, no-store, no-transform'}, data=payload)
         open("/tmp/jira_email_user_%s.html" % user, "w").write(r.content)
         # return False
 
@@ -1790,7 +1776,7 @@ class JIRA(object):
             "RunCanned": "Run",
         }
 
-        logging.debug("renaming %s" % self.user(old_user).emailAddress)  # raw displayName
+        print(self.user(old_user).emailAddress)  # raw displayName
 
         r = self._session.post(url, headers={'X-Atlassian-Token': 'nocheck', 'Cache-Control': 'no-cache'}, data=payload)
         if r.status_code == 404:
@@ -2187,7 +2173,7 @@ class GreenHopper(JIRA):
         """
         Return the completed issues for the given board id and sprint id
         """
-        r_json = self._get_json('rapid/charts/sprintreport?rapidViewId=%s&sprintId=%s' % (board_id, sprint_id), self.GREENHOPPER_BASE_URL)
+        r_json = self._get_json('rapid/charts/sprintreport?rapidViewId=%s&sprintId=%s' % (board_id, sprint_id), base=self.GREENHOPPER_BASE_URL)
         issues = [Issue(self._options, self._session, raw_issues_json) for raw_issues_json in r_json['contents']['incompletedIssues']]
         return issues
 
@@ -2309,3 +2295,13 @@ class GreenHopper(JIRA):
         url = self._get_url('rank', base=self.GREENHOPPER_BASE_URL)
         r = self._session.put(url, data=json.dumps(data), headers={'Content-Type': 'application/json'})
         raise_on_error(r)
+
+if __name__ == '__main__':
+    url = 'http://issues.apache.org/jira'
+    print("1")
+    jira = JIRA(url)
+    print("2")
+    jira = JIRA(options={'server': url})
+    print("3 (should see a warning)")
+    j = JIRA({'server': url})
+    print(jira.issue('INFRA-7976'))
